==> haskell-nonce-1.0.4-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nonce
version: 1.0.4
id: nonce-1.0.4-FVKGUgg7dPV4209OR2WmDT
key: nonce-1.0.4-FVKGUgg7dPV4209OR2WmDT
license: BSD3
copyright: (c) 2014 Prowdsponsor
maintainer: Prowdsponsor <opensource@prowdsponsor.com>
homepage: https://github.com/prowdsponsor/nonce
synopsis: Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.
    .
    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.
category: Cryptography
author: Felipe Lessa <felipe.lessa@prowdsponsor.com>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Nonce
abi: 2e9329a6d3dfb20f9af789218f672b5d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/nonce-1.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/nonce-1.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/nonce-1.0.4
hs-libraries: HSnonce-1.0.4-FVKGUgg7dPV4209OR2WmDT
depends:
    base-4.10.1.0 base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    bytestring-0.10.8.2 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    transformers-0.5.2.0 entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             entropy-0.3.8-459fr1KgYZzBPF08mWgtQU=48b904d4ac32d9c7078ceefe10d1973a
haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html: /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nonce-1.0.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nonce
version: 1.0.5
id: nonce-1.0.5-F3Nk63eFCyl4CmHL9ssb0v
key: nonce-1.0.5-F3Nk63eFCyl4CmHL9ssb0v
license: BSD3
copyright: (c) 2014 Prowdsponsor
maintainer: Prowdsponsor <opensource@prowdsponsor.com>
homepage: https://github.com/prowdsponsor/nonce
synopsis: Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.
    .
    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.
category: Cryptography
author: Felipe Lessa <felipe.lessa@prowdsponsor.com>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Nonce
abi: 3d746060e3992f6d2a6d4dce4ef73eef
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/nonce-1.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/nonce-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/nonce-1.0.5
hs-libraries: HSnonce-1.0.5-F3Nk63eFCyl4CmHL9ssb0v
depends:
    base-4.10.1.0 base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    bytestring-0.10.8.2 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    transformers-0.5.2.0 entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
    unliftio-0.2.0.0-DPEvFNEeGNn1rUtGr8Usk6
    unliftio-core-0.1.0.0-9rQX9ZUGZDTAHFduIwCNuu
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             entropy-0.3.8-459fr1KgYZzBPF08mWgtQU=48b904d4ac32d9c7078ceefe10d1973a
             unliftio-0.2.0.0-DPEvFNEeGNn1rUtGr8Usk6=65f4596334f653851cf054f43f81e4dc
             unliftio-core-0.1.0.0-9rQX9ZUGZDTAHFduIwCNuu=d0f710e39d0e95f44d3d5f4052af677a
haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html: /usr/share/doc/haskell-nonce/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
